%define anolis_release 1

%global with_tests 0

Name:           mosquitto
Version:        2.0.15
Release:        %{anolis_release}%{?dist}
Summary:        Open Source MQTT v5/v3.1.x Broker

License:        EPL-2.0
URL:            https://mosquitto.org/
Source0:        https://mosquitto.org/files/source/%{name}-%{version}.tar.gz

BuildRequires:  c-ares-devel
BuildRequires:  cjson-devel
BuildRequires:  gcc-c++
BuildRequires:  libuuid-devel
BuildRequires:  libwebsockets-devel
BuildRequires:  make
BuildRequires:  openssl-devel
BuildRequires:  systemd-devel
%if 0%{?with_tests}
BuildRequires:  CUnit-devel
%endif
Provides: bundled(uthash)

Requires(pre):    shadow-utils
Requires(post):   systemd
Requires(preun):  systemd
Requires(postun): systemd

%description
Mosquitto is an open source message broker that implements the MQ Telemetry
Transport protocol version 3.1 and 3.1.1 MQTT provides a lightweight method
of carrying out messaging using a publish/subscribe model. This makes it
suitable for "machine to machine" messaging such as with low power sensors 
or mobile devices such as phones, embedded computers or micro-controllers 
like the Arduino.

%package devel
Requires:     %{name} = %{version}-%{release}
Summary:      Development files for %{name}

%description devel
Development headers and libraries for %{name}.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1
# Set the install prefix to /usr
sed -i "s|prefix?=/usr/local|prefix?=/usr|" config.mk
# Don't strip binaries on install: rpmbuild will take care of it
sed -i "s|(INSTALL) -s|(INSTALL)|g" lib/Makefile src/Makefile client/Makefile

%build
#export CFLAGS="%{optflags} -std=gnu99"
export CFLAGS="%{optflags}"
export LDFLAGS="%{optflags} %{__global_ldflags} -Wl,--as-needed"
make all %{?_smp_mflags} WITH_WEBSOCKETS=yes WITH_SYSTEMD=yes WITH_SRV=yes

%install
%if "%{_lib}" == "lib64"
export LIB_SUFFIX=64
%endif
%make_install

mkdir -p %{buildroot}%{_unitdir}
install -p -m 0644 service/systemd/%{name}.service.notify %{buildroot}%{_unitdir}/%{name}.service
mv %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf.example %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf

%generate_compatibility_deps

%if 0%{?with_tests}
%check
make test
%endif

%pre
getent group %{name} >/dev/null || groupadd -r %{name}
getent passwd %{name} >/dev/null || \
    useradd -r -g %{name} -d %{_sysconfdir}/%{name} -s /sbin/nologin \
    -c "Mosquitto Broker" %{name}
exit 0

%post
%systemd_post %{name}.service
/sbin/ldconfig

%preun
%systemd_preun %{name}.service

%postun
%systemd_postun_with_restart %{name}.service
/sbin/ldconfig

%files
%license LICENSE.txt 
%dir %{abidir}
%{_bindir}/%{name}*
%{_sbindir}/%{name}
%{_libdir}/libmosquitto*.so.1
%{_libdir}/mosquitto_dynamic_security.so
%{abidir}/libmosquitto*.dump
%{abidir}/mosquitto_dynamic_security.dump
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%config %{_sysconfdir}/%{name}/*.example
%{_unitdir}/%{name}.service
%{_mandir}/man*/%{name}*
%{_mandir}/man7/mqtt.7.*

%files devel
%{_includedir}/mosquitto*.h
%{_includedir}/mqtt*.h
%{_libdir}/libmosquitto*.so
%{_libdir}/pkgconfig/libmosquitto*.pc
%{_mandir}/man3/libmosquitto.3.*

%files doc
%doc ChangeLog.txt CONTRIBUTING.md README.md

%changelog
* Mon Jul 17 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.0.15-1
- Init upstream from version 2.0.15
